==> digikam-6.1.0.tar.xz: digikam-6.1.0/core/dplugins/bqm/metadata/timeadjust/timeadjust.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2009-03-04
 * Description : a tool to adjust date time stamp of images
 *
 * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef DIGIKAM_BQM_TIME_ADJUST_H
#define DIGIKAM_BQM_TIME_ADJUST_H

// Local includes

#include "batchtool.h"
#include "timeadjustsettings.h"

using namespace Digikam;

namespace DigikamBqmTimeAdjustPlugin
{

class TimeAdjust : public BatchTool
{
    Q_OBJECT

public:

    explicit TimeAdjust(QObject* const parent = 0);
    virtual ~TimeAdjust();

    BatchToolSettings defaultSettings();

    BatchTool* clone(QObject* const parent=0) const
    {
        return new TimeAdjust(parent);
    };

    void registerSettingsWidget();

private:

    bool toolOperations();

private Q_SLOTS:

    void slotAssignSettings2Widget();
    void slotSettingsChanged();

private:

    TimeAdjustSettings* m_taWidget;
    int                 m_changeSettings;
};

} // namespace DigikamBqmTimeAdjustPlugin

#endif // DIGIKAM_BQM_TIME_ADJUST_H

==> digikam_6.4.0+dfsg.orig.tar.xz: digikam-6.4.0+dfsg/core/dplugins/bqm/metadata/timeadjust/timeadjust.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2009-03-04
 * Description : a tool to adjust date time stamp of images
 *
 * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef DIGIKAM_BQM_TIME_ADJUST_H
#define DIGIKAM_BQM_TIME_ADJUST_H

// Local includes

#include "batchtool.h"
#include "timeadjustsettings.h"

using namespace Digikam;

namespace DigikamBqmTimeAdjustPlugin
{

class TimeAdjust : public BatchTool
{
    Q_OBJECT

public:

    explicit TimeAdjust(QObject* const parent = nullptr);
    virtual ~TimeAdjust();

    BatchToolSettings defaultSettings();

    BatchTool* clone(QObject* const parent=nullptr) const
    {
        return new TimeAdjust(parent);
    };

    void registerSettingsWidget();

private:

    bool toolOperations();

private Q_SLOTS:

    void slotAssignSettings2Widget();
    void slotSettingsChanged();

private:

    TimeAdjustSettings* m_taWidget;
    int                 m_changeSettings;
};

} // namespace DigikamBqmTimeAdjustPlugin

#endif // DIGIKAM_BQM_TIME_ADJUST_H
